
class WhoIsQueryError(Exception):
    pass


class WhoIsParserError(Exception):
    pass
